## 0.6.0 (2022-06-21)

[stubsabot] Bump editdistance to 0.6.* (#8120)

Co-authored-by: hauntsaninja <>

## 0.5.3 (2022-04-16)

Third-party stubs: import from `collections.abc` where possible (#7637)

## 0.5.1 (2021-10-12)

Add star to all non-0.1 versions (#6146)

